function [DutyCycles,Frequency]=DutyCycleGenerator(Power,numDay,EtoP)
% The program is to generate duty cycle matrix with unique types and
% its corresponding frequencies (probabilities)
% In order to employ the most representative cycles for battery testing 

%{
Output: 
   Dutycycles - All types of duty cycles occurred in this time periods 
                Sort in descending order by corresponding frequencies
   Frequency  - The frequencies and probabilities of each type of cycle
%}

% Power vector is the 2 years outcome from dispatcer with respect E/P ratio
T=numel(Power);
numPeriod = T/numDay;
Power=round(Power,4);
Power=reshape(Power,numPeriod,numDay)'; % Reshape the Power into 730x24 matrix

% Produce the daily duty cycle matrix for two years without breaks
% If no break between two same dispatches, set as continuous 1 dispatch
% If there is breaks between, set as two dispatches
dutycycle=nan(numDay,numPeriod);

% For P/E Ratio=1
%{
for i=1:T/24
    d=PowerDA(i,:);
    DutyCycle(i,:)=[d(d~=0) zeros(1,sum(d==0))];
end;
%}

% For P/E Ratio >= 1
for i=1:numDay
    d=Power(i,:); % Daily duty cycle
    cycle=[];
    if d(1)~=0
        cycle=d(1);
    end;
    for j=2:numPeriod
        if d(j)==0
            cycle=cycle;
        elseif (d(j)==d(j-1) && length(cycle)==1 && d(j)~=0)
            cycle=cycle+d(j);
        elseif (d(j)==d(j-1) && length(cycle)>1 && d(j)~=0)
            cycle=[cycle(1:end-1) cycle(end)+d(j)];
        elseif (d(j)~=d(j-1) && d(j)~=0)
            cycle=[cycle d(j)];
        end;
    end;
    dutycycle(i,:)=[cycle zeros(1,numPeriod-length(cycle))];
end;

% Generate each unique row and its frequency
[Dutycycles,~,ind] = unique(dutycycle,'rows');
counts = histc(ind,unique(ind));
[counts,I]=sort(counts,'descend');
DutyCycles=Dutycycles(I,:);
Frequency=nan(size(DutyCycles,1),2);
Frequency(:,1)=counts;Frequency(:,2)=counts./730;
% Save duty cycle matrix for this application and its probability
%save(strcat('DutyCycleDA_EP',num2str(EtoP)),'DutyCycles','Frequency');